Learn R Programming

bambooHR (version 0.1.1)

bambooHR-package: bambooHR: A Wrapper to the 'BambooHR' API

Description

Enables a user to consume the 'BambooHR' API endpoints using R. The actual URL of the API will depend on your company domain, and will be handled by the package automatically once you setup the config file. The API documentation can be found here https://documentation.bamboohr.com/docs.

Arguments

Author

Maintainer: Tom Bowling tom.bowling@ascent.io

Authors:

Other contributors:

See Also