Used to generate the base API request URL. URLs will start with "https://api.bamboohr.com/api/gateway.php/company_domain" which forms the base URL where a query string can then be appended to make the full request URL.
build_url(
company_domain = .get_company_name(),
api_version = "v1",
base_url = "https://api.bamboohr.com/api/gateway.php"
)character vector of URL with API version and company domain to give the base URL for API requests.
The subdomain used to access BambooHR. If you access BambooHR at https://mycompany.bamboohr.com, then the company_domain is "mycompany".
Default value is obtained from options("bambooHR.company_name"). This can also be set in the config file using config_setup("api key", "company_domain").
Version of API to use to make request. Default is "v1".
URL to BambooHR API. Default is "https://api.bamboohr.com/api/gateway.php".