get_employee: Get employee data by specifying a set of fields.
Description
This is suitable for getting basic employee information, including current
values for fields that are part of a historical table, like job title,
or compensation information. See the fields endpoint for a list of possible
fields.
Tibble (dataframe), unless [verbose = TRUE] and [id = "directory"],
in which case a list with the fields dataframe and the directory dataframe.
Arguments
id
Employee IDs (character or numeric). The default of "directory"
will give a directory of all employees, along with a table of possible fields.
The special employee ID of zero (0) means to use the employee ID associated
with the API key (if any).
fields
Character vector of fields to return. To see all available fields,
see the column names of get_employee().
only_current
Setting to false will return future dated values from
history table fields.
verbose
Logical, default FALSE. Whether to return the fields dataframe
when [id = "directory"].
api_version
(optional) - Version of API to use to make request. Default is "v1".