Request one of your pre-existing company reports from the reporting section. At present, only reports from the Company Reports section are supported.
get_report(
id,
format = c("CSV", "PDF", "XLS", "XML", "JSON"),
field_filtering = TRUE,
only_current = TRUE,
api_version = "v1"
)Currently the function simply returns a parsed response object.
The report ID. You can get the report number by hovering over the report name on the reports page and grabbing the ID.
The output format for the report. Supported formats: CSV, PDF, XLS, XML, JSON.
Logical, default [TRUE]. Whether to apply duplicate field filtering.
Logical default [TRUE]. Should the report be limited to only current employees.
(optional) - Version of API to use to make request. Default is "v1".