Learn R Programming

bambooHR (version 0.1.1)

get_timeoff_policies: Get Time Off policies

Description

Wrapper to get_meta function that returns a list of time off policies.

Usage

get_timeoff_policies()

Arguments

Value

A httr::response() object where the content is a JSON format that contains the list of time off policies.

References

https://documentation.bamboohr.com/reference/get-time-off-policies

Examples

Run this code
if (FALSE) {
res <- get_timeoff_policies()
httr::content(res, "parsed")
}

Run the code above in your browser using DataLab