powered by
Wrapper to get_meta function that returns a list of time off policies.
get_timeoff_policies()
A httr::response() object where the content is a JSON format that contains the list of time off policies.
httr::response()
https://documentation.bamboohr.com/reference/get-time-off-policies
if (FALSE) { res <- get_timeoff_policies() httr::content(res, "parsed") }
Run the code above in your browser using DataLab